@@ -118,10 +118,7 @@ type KubeletConfigSpec struct {
 	ReconcileCIDR *bool `json:"reconcileCIDR,omitempty" flag:"reconcile-cidr"`
 	// registerSchedulable tells the kubelet to register the node as schedulable. No-op if register-node is false.
 	RegisterSchedulable *bool `json:"registerSchedulable,omitempty" flag:"register-schedulable"`
-	//// SerializeImagePulls when enabled, tells the Kubelet to pull images one
-	//// at a time. We recommend *not* changing the default value on nodes that
-	//// run docker daemon with version  < 1.9 or an Aufs storage backend.
-	//// Issue #10959 has more details.
+	// SerializeImagePulls when enabled, tells the Kubelet to pull images one at a time.
 	SerializeImagePulls *bool `json:"serializeImagePulls,omitempty" flag:"serialize-image-pulls"`
 	// NodeLabels to add when registering the node in the cluster.
 	NodeLabels map[string]string `json:"nodeLabels,omitempty" flag:"node-labels"`
@@ -192,8 +189,8 @@ type KubeletConfigSpec struct {
 	AllowedUnsafeSysctls []string `json:"allowedUnsafeSysctls,omitempty" flag:"allowed-unsafe-sysctls"`
 	// StreamingConnectionIdleTimeout is the maximum time a streaming connection can be idle before the connection is automatically closed
 	StreamingConnectionIdleTimeout *metav1.Duration `json:"streamingConnectionIdleTimeout,omitempty" flag:"streaming-connection-idle-timeout"`
-	// DockerDisableSharedPID uses a shared PID namespace for containers in a pod.
-	DockerDisableSharedPID *bool `json:"dockerDisableSharedPID,omitempty" flag:"docker-disable-shared-pid"`
+	// DockerDisableSharedPID was removed.
+	DockerDisableSharedPID *bool `json:"-"`
 	// RootDir is the directory path for managing kubelet files (volume mounts,etc)
 	RootDir string `json:"rootDir,omitempty" flag:"root-dir"`
 	// AuthenticationTokenWebhook uses the TokenReview API to determine authentication for bearer tokens.
@@ -292,7 +289,7 @@ type KubeProxyConfig struct {
 
 // KubeAPIServerConfig defines the configuration for the kube api
 type KubeAPIServerConfig struct {
-	// Image is the docker container used
+	// Image is the container image used.
 	Image string `json:"image,omitempty"`
 	// DisableBasicAuth removes the --basic-auth-file flag
 	DisableBasicAuth *bool `json:"disableBasicAuth,omitempty"`
@@ -532,6 +529,8 @@ type KubeAPIServerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 
 	// CorsAllowedOrigins is a list of origins for CORS. An allowed origin can be a regular
 	// expression to support subdomain matching. If this list is empty CORS will not be enabled.
@@ -555,7 +554,7 @@ type KubeControllerManagerConfig struct {
 	LogLevel int32 `json:"logLevel,omitempty" flag:"v" flag-empty:"0"`
 	// ServiceAccountPrivateKeyFile is the location of the private key for service account token signing.
 	ServiceAccountPrivateKeyFile string `json:"serviceAccountPrivateKeyFile,omitempty" flag:"service-account-private-key-file"`
-	// Image is the docker image to use
+	// Image is the container image to use.
 	Image string `json:"image,omitempty"`
 	// CloudProvider is the provider for cloud services.
 	CloudProvider string `json:"cloudProvider,omitempty" flag:"cloud-provider"`
@@ -663,6 +662,10 @@ type KubeControllerManagerConfig struct {
 	ConcurrentServiceaccountTokenSyncs *int32 `json:"concurrentServiceaccountTokenSyncs,omitempty" flag:"concurrent-serviceaccount-token-syncs"`
 	// The number of replicationcontroller objects that are allowed to sync concurrently.
 	ConcurrentRCSyncs *int32 `json:"concurrentRCSyncs,omitempty" flag:"concurrent-rc-syncs"`
+	// The number of horizontal pod autoscaler objects that are allowed to sync concurrently (default 5).
+	ConcurrentHorizontalPodAustoscalerSyncs *int32 `json:"concurrentHorizontalPodAustoscalerSyncs,omitempty" flag:"concurrent-horizontal-pod-autoscaler-syncs"`
+	// The number of job objects that are allowed to sync concurrently (default 5).
+	ConcurrentJobSyncs *int32 `json:"concurrentJobSyncs,omitempty" flag:"concurrent-job-syncs"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -684,6 +687,8 @@ type KubeControllerManagerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 	// EnableLeaderMigration enables controller leader migration.
 	EnableLeaderMigration *bool `json:"enableLeaderMigration,omitempty" flag:"enable-leader-migration"`
 }
@@ -724,6 +729,8 @@ type CloudControllerManagerConfig struct {
 	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// NodeStatusUpdateFrequency is the duration between node status updates. (default: 5m)
 	NodeStatusUpdateFrequency *metav1.Duration `json:"nodeStatusUpdateFrequency,omitempty" flag:"node-status-update-frequency"`
+	// ConcurrentNodeSyncs is the number of workers concurrently synchronizing nodes. (default: 1)
+	ConcurrentNodeSyncs *int32 `json:"concurrentNodeSyncs,omitempty" flag:"concurrent-node-syncs"`
 }
 
 // KubeSchedulerConfig is the configuration for the kube-scheduler
@@ -736,11 +743,12 @@ type KubeSchedulerConfig struct {
 	LogFormat string `json:"logFormat,omitempty" flag:"logging-format" flag-empty:"text"`
 	// LogLevel is the logging level
 	LogLevel int32 `json:"logLevel,omitempty" flag:"v"`
-	// Image is the docker image to use
+	// Image is the container image to use.
 	Image string `json:"image,omitempty"`
 	// LeaderElection defines the configuration of leader election client.
 	LeaderElection *LeaderElectionConfiguration `json:"leaderElection,omitempty"`
 	// UsePolicyConfigMap enable setting the scheduler policy from a configmap
+	// Deprecated - use KubeSchedulerConfiguration instead
 	UsePolicyConfigMap *bool `json:"usePolicyConfigMap,omitempty"`
 	// FeatureGates is set of key=value pairs that describe feature gates for alpha/experimental features.
 	FeatureGates map[string]string `json:"featureGates,omitempty" flag:"feature-gates"`
@@ -753,6 +761,10 @@ type KubeSchedulerConfig struct {
 	Qps *resource.Quantity `json:"qps,omitempty" configfile:"ClientConnection.QPS" config:"clientConnection.qps,omitempty"`
 	// Burst sets the maximum qps to send to apiserver after the burst quota is exhausted
 	Burst int32 `json:"burst,omitempty" configfile:"ClientConnection.Burst" config:"clientConnection.burst,omitempty"`
+	// KubeAPIQPS QPS to use while talking with kubernetes apiserver. (default 20)
+	KubeAPIQPS *resource.Quantity `json:"kubeAPIQPS,omitempty" flag:"kube-api-qps"`
+	// KubeAPIBurst Burst to use while talking with kubernetes apiserver. (default 30)
+	KubeAPIBurst *int32 `json:"kubeAPIBurst,omitempty" flag:"kube-api-burst"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -762,6 +774,8 @@ type KubeSchedulerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 	// TLSCertFile is the file containing the TLS server certificate.
 	TLSCertFile *string `json:"tlsCertFile,omitempty" flag:"tls-cert-file"`
 	// TLSPrivateKeyFile is the file containing the private key for the TLS server certificate.
@@ -896,9 +910,9 @@ type CloudConfiguration struct {
 
 // EBSCSIDriverSpec is the config for the AWS EBS CSI driver
 type EBSCSIDriverSpec struct {
-	// Enabled enables the AWS EBS CSI driver
-	// Default: false
-	Enabled *bool `json:"enabled,omitempty"`
+	// Enabled enables the AWS EBS CSI driver. Can only be set to true.
+	// Default: true
+	Enabled *bool `json:"-"`
 
 	// Managed controls if aws-ebs-csi-driver is manged and deployed by kOps.
 	// The deployment of aws-ebs-csi-driver is skipped if this is set to false.
@@ -908,6 +922,15 @@ type EBSCSIDriverSpec struct {
 	// Default: The latest stable release which is compatible with your Kubernetes version
 	Version *string `json:"version,omitempty"`
 
+	// KubeAPIQPS QPS to use while talking with Kubernetes API server. (default 20)
+	KubeAPIQPS *resource.Quantity `json:"kubeAPIQPS,omitempty"`
+	// KubeAPIBurst Burst to use while talking with Kubernetes API server. (default 100)
+	KubeAPIBurst *int32 `json:"kubeAPIBurst,omitempty"`
+
+	// HostNetwork can be used for large clusters for faster access to node info via instance metadata.
+	// Default: false
+	HostNetwork bool `json:"hostNetwork,omitempty"`
+
 	// VolumeAttachLimit is the maximum number of volumes attachable per node.
 	// If specified, the limit applies to all nodes.
 	// If not specified, the value is approximated from the instance type.
@@ -979,6 +1002,9 @@ type NodeTerminationHandlerSpec struct {
 	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// Version is the container image tag used.
 	Version *string `json:"version,omitempty"`
+
+	// If specified, posts event data to URL upon instance interruption action.
+	WebhookURL *string `json:"webhookURL,omitempty"`
 }
 
 func (n *NodeTerminationHandlerSpec) IsQueueMode() bool {
@@ -990,7 +1016,7 @@ type NodeProblemDetectorConfig struct {
 	// Enabled enables the NodeProblemDetector.
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
-	// Image is the NodeProblemDetector docker container used.
+	// Image is the NodeProblemDetector container image used.
 	Image *string `json:"image,omitempty"`
 
 	// MemoryRequest of NodeProblemDetector container.
@@ -1030,6 +1056,9 @@ type ClusterAutoscalerConfig struct {
 	// ScaleDownUtilizationThreshold determines the utilization threshold for node scale-down.
 	// Default: 0.5
 	ScaleDownUtilizationThreshold *string `json:"scaleDownUtilizationThreshold,omitempty"`
+	// SkipNodesWithCustomControllerPods makes the cluster autoscaler skip scale-down of nodes with pods owned by custom controllers.
+	// Default: true
+	SkipNodesWithCustomControllerPods *bool `json:"skipNodesWithCustomControllerPods,omitempty"`
 	// SkipNodesWithSystemPods makes the cluster autoscaler skip scale-down of nodes with non-DaemonSet pods in the kube-system namespace.
 	// Default: true
 	SkipNodesWithSystemPods *bool `json:"skipNodesWithSystemPods,omitempty"`
@@ -1051,7 +1080,7 @@ type ClusterAutoscalerConfig struct {
 	// CordonNodeBeforeTerminating should CA cordon nodes before terminating during downscale process
 	// Default: false
 	CordonNodeBeforeTerminating *bool `json:"cordonNodeBeforeTerminating,omitempty"`
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 	// MemoryRequest of cluster autoscaler container.
@@ -1078,7 +1107,7 @@ type MetricsServerConfig struct {
 	// Enabled enables the metrics server.
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 	// Insecure determines if API server will validate metrics server TLS cert.
@@ -1096,7 +1125,7 @@ type CertManagerConfig struct {
 	// The deployment of cert-manager is skipped if this is set to false.
 	Managed *bool `json:"managed,omitempty"`
 
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 
@@ -1110,6 +1139,9 @@ type CertManagerConfig struct {
 
 	// HostedZoneIDs is a list of route53 hostedzone IDs that cert-manager will be allowed to do dns-01 validation for
 	HostedZoneIDs []string `json:"hostedZoneIDs,omitempty"`
+
+	// FeatureGates is a list of experimental features that can be enabled or disabled.
+	FeatureGates map[string]bool `json:"featureGates,omitempty"`
 }
 
 // LoadBalancerControllerSpec determines the AWS LB controller configuration.
