@@ -117,10 +117,7 @@ type KubeletConfigSpec struct {
 	ReconcileCIDR *bool `json:"-"`
 	// registerSchedulable is not admin-configurable.
 	RegisterSchedulable *bool `json:"-"`
-	//// SerializeImagePulls when enabled, tells the Kubelet to pull images one
-	//// at a time. We recommend *not* changing the default value on nodes that
-	//// run docker daemon with version  < 1.9 or an Aufs storage backend.
-	//// Issue #10959 has more details.
+	// SerializeImagePulls when enabled, tells the Kubelet to pull images one at a time.
 	SerializeImagePulls *bool `json:"serializeImagePulls,omitempty" flag:"serialize-image-pulls"`
 	// NodeLabels is not admin-configurable.
 	NodeLabels map[string]string `json:"-"`
@@ -290,7 +287,7 @@ type KubeProxyConfig struct {
 
 // KubeAPIServerConfig defines the configuration for the kube api
 type KubeAPIServerConfig struct {
-	// Image is the docker container used
+	// Image is the container image used.
 	Image string `json:"image,omitempty"`
 	// DisableBasicAuth removes the --basic-auth-file flag
 	DisableBasicAuth *bool `json:"disableBasicAuth,omitempty"`
@@ -530,6 +527,8 @@ type KubeAPIServerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 
 	// CorsAllowedOrigins is a list of origins for CORS. An allowed origin can be a regular
 	// expression to support subdomain matching. If this list is empty CORS will not be enabled.
@@ -553,7 +552,7 @@ type KubeControllerManagerConfig struct {
 	LogLevel int32 `json:"logLevel,omitempty" flag:"v" flag-empty:"0"`
 	// ServiceAccountPrivateKeyFile is not admin-configurable.
 	ServiceAccountPrivateKeyFile string `json:"-"`
-	// Image is the docker image to use
+	// Image is the container image to use.
 	Image string `json:"image,omitempty"`
 	// CloudProvider is the provider for cloud services.
 	CloudProvider string `json:"cloudProvider,omitempty" flag:"cloud-provider"`
@@ -662,6 +661,10 @@ type KubeControllerManagerConfig struct {
 	// The number of replicationcontroller objects that are allowed to sync concurrently.
 	// This only works on kubernetes >= 1.14
 	ConcurrentRCSyncs *int32 `json:"concurrentRCSyncs,omitempty" flag:"concurrent-rc-syncs"`
+	// The number of horizontal pod autoscaler objects that are allowed to sync concurrently (default 5).
+	ConcurrentHorizontalPodAustoscalerSyncs *int32 `json:"concurrentHorizontalPodAustoscalerSyncs,omitempty" flag:"concurrent-horizontal-pod-autoscaler-syncs"`
+	// The number of job objects that are allowed to sync concurrently (default 5).
+	ConcurrentJobSyncs *int32 `json:"concurrentJobSyncs,omitempty" flag:"concurrent-job-syncs"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -681,6 +684,8 @@ type KubeControllerManagerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 	// EnableLeaderMigration enables controller leader migration.
 	EnableLeaderMigration *bool `json:"enableLeaderMigration,omitempty" flag:"enable-leader-migration"`
 }
@@ -721,6 +726,8 @@ type CloudControllerManagerConfig struct {
 	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// NodeStatusUpdateFrequency is the duration between node status updates. (default: 5m)
 	NodeStatusUpdateFrequency *metav1.Duration `json:"nodeStatusUpdateFrequency,omitempty" flag:"node-status-update-frequency"`
+	// ConcurrentNodeSyncs is the number of workers concurrently synchronizing nodes. (default: 1)
+	ConcurrentNodeSyncs *int32 `json:"concurrentNodeSyncs,omitempty" flag:"concurrent-node-syncs"`
 }
 
 // KubeSchedulerConfig is the configuration for the kube-scheduler
@@ -733,11 +740,12 @@ type KubeSchedulerConfig struct {
 	LogFormat string `json:"logFormat,omitempty" flag:"logging-format" flag-empty:"text"`
 	// LogLevel is the logging level
 	LogLevel int32 `json:"logLevel,omitempty" flag:"v"`
-	// Image is the docker image to use
+	// Image is the container image to use.
 	Image string `json:"image,omitempty"`
 	// LeaderElection defines the configuration of leader election client.
 	LeaderElection *LeaderElectionConfiguration `json:"leaderElection,omitempty"`
 	// UsePolicyConfigMap enable setting the scheduler policy from a configmap
+	// Deprecated - use KubeSchedulerConfiguration instead
 	UsePolicyConfigMap *bool `json:"usePolicyConfigMap,omitempty"`
 	// FeatureGates is set of key=value pairs that describe feature gates for alpha/experimental features.
 	FeatureGates map[string]string `json:"featureGates,omitempty" flag:"feature-gates"`
@@ -750,6 +758,10 @@ type KubeSchedulerConfig struct {
 	Qps *resource.Quantity `json:"qps,omitempty"`
 	// Burst sets the maximum qps to send to apiserver after the burst quota is exhausted
 	Burst int32 `json:"burst,omitempty"`
+	// KubeAPIQPS QPS to use while talking with kubernetes apiserver. (default 20)
+	KubeAPIQPS *resource.Quantity `json:"kubeAPIQPS,omitempty" flag:"kube-api-qps"`
+	// KubeAPIBurst Burst to use while talking with kubernetes apiserver. (default 30)
+	KubeAPIBurst *int32 `json:"kubeAPIBurst,omitempty" flag:"kube-api-burst"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -759,6 +771,8 @@ type KubeSchedulerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableContentionProfiling enables block profiling, if profiling is enabled
+	EnableContentionProfiling *bool `json:"enableContentionProfiling,omitempty" flag:"contention-profiling"`
 	// TLSCertFile is the file containing the TLS server certificate.
 	TLSCertFile *string `json:"tlsCertFile,omitempty" flag:"tls-cert-file"`
 	// TLSPrivateKeyFile is the file containing the private key for the TLS server certificate.
@@ -893,9 +907,8 @@ type CloudConfiguration struct {
 
 // EBSCSIDriverSpec is the config for the AWS EBS CSI driver
 type EBSCSIDriverSpec struct {
-	// Enabled enables the AWS EBS CSI driver
-	// Default: false
-	Enabled *bool `json:"enabled,omitempty"`
+	// Enabled enables the AWS EBS CSI driver.
+	Enabled *bool `json:"-"`
 
 	// Managed controls if aws-ebs-csi-driver is manged and deployed by kOps.
 	// The deployment of aws-ebs-csi-driver is skipped if this is set to false.
@@ -905,6 +918,15 @@ type EBSCSIDriverSpec struct {
 	// Default: The latest stable release which is compatible with your Kubernetes version
 	Version *string `json:"version,omitempty"`
 
+	// KubeAPIQPS QPS to use while talking with Kubernetes API server. (default 20)
+	KubeAPIQPS *resource.Quantity `json:"kubeAPIQPS,omitempty"`
+	// KubeAPIBurst Burst to use while talking with Kubernetes API server. (default 100)
+	KubeAPIBurst *int32 `json:"kubeAPIBurst,omitempty"`
+
+	// HostNetwork can be used for large clusters for faster access to node info via instance metadata.
+	// Default: false
+	HostNetwork bool `json:"hostNetwork,omitempty"`
+
 	// VolumeAttachLimit is the maximum number of volumes attachable per node.
 	// If specified, the limit applies to all nodes.
 	// If not specified, the value is approximated from the instance type.
@@ -976,6 +998,9 @@ type NodeTerminationHandlerSpec struct {
 	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// Version is the container image tag used.
 	Version *string `json:"version,omitempty"`
+
+	// If specified, posts event data to URL upon instance interruption action.
+	WebhookURL *string `json:"webhookURL,omitempty"`
 }
 
 // NodeProblemDetector determines the node problem detector configuration.
@@ -983,7 +1008,7 @@ type NodeProblemDetectorConfig struct {
 	// Enabled enables the NodeProblemDetector.
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
-	// Image is the NodeProblemDetector docker container used.
+	// Image is the NodeProblemDetector container image used.
 	Image *string `json:"image,omitempty"`
 
 	// MemoryRequest of NodeProblemDetector container.
@@ -1023,6 +1048,9 @@ type ClusterAutoscalerConfig struct {
 	// ScaleDownUtilizationThreshold determines the utilization threshold for node scale-down.
 	// Default: 0.5
 	ScaleDownUtilizationThreshold *string `json:"scaleDownUtilizationThreshold,omitempty"`
+	// SkipNodesWithCustomControllerPods makes the cluster autoscaler skip scale-down of nodes with pods owned by custom controllers.
+	// Default: true
+	SkipNodesWithCustomControllerPods *bool `json:"skipNodesWithCustomControllerPods,omitempty"`
 	// SkipNodesWithSystemPods makes the cluster autoscaler skip scale-down of nodes with non-DaemonSet pods in the kube-system namespace.
 	// Default: true
 	SkipNodesWithSystemPods *bool `json:"skipNodesWithSystemPods,omitempty"`
@@ -1044,7 +1072,7 @@ type ClusterAutoscalerConfig struct {
 	// CordonNodeBeforeTerminating should CA cordon nodes before terminating during downscale process
 	// Default: false
 	CordonNodeBeforeTerminating *bool `json:"cordonNodeBeforeTerminating,omitempty"`
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 	// MemoryRequest of cluster autoscaler container.
@@ -1071,7 +1099,7 @@ type MetricsServerConfig struct {
 	// Enabled enables the metrics server.
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 	// Insecure determines if API server will validate metrics server TLS cert.
@@ -1089,7 +1117,7 @@ type CertManagerConfig struct {
 	// The deployment of cert-manager is skipped if this is set to false.
 	Managed *bool `json:"managed,omitempty"`
 
-	// Image is the docker container used.
+	// Image is the container image used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
 
@@ -1103,6 +1131,9 @@ type CertManagerConfig struct {
 
 	// HostedZoneIDs is a list of route53 hostedzone IDs that cert-manager will be allowed to do dns-01 validation for
 	HostedZoneIDs []string `json:"hostedZoneIDs,omitempty"`
+
+	// FeatureGates is a list of experimental features that can be enabled or disabled.
+	FeatureGates map[string]bool `json:"featureGates,omitempty"`
 }
 
 // LoadBalancerControllerSpec determines the AWS LB controller configuration.
