@@ -26,6 +26,7 @@ import (
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/aws/request"
 	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"github.com/aws/aws-sdk-go/service/autoscaling/autoscalingiface"
 	"github.com/aws/aws-sdk-go/service/ec2"
@@ -137,6 +138,8 @@ func (v *assertNotCalledClusterValidator) Validate() (*validation.ValidationClus
 }
 
 func makeGroup(groups map[string]*cloudinstances.CloudInstanceGroup, k8sClient kubernetes.Interface, cloud awsup.AWSCloud, name string, role kopsapi.InstanceGroupRole, count int, needUpdate int) {
+	ctx := context.TODO()
+
 	fakeClient := k8sClient.(*fake.Clientset)
 
 	group := &cloudinstances.CloudInstanceGroup{
@@ -153,7 +156,7 @@ func makeGroup(groups map[string]*cloudinstances.CloudInstanceGroup, k8sClient k
 	}
 	groups[name] = group
 
-	cloud.Autoscaling().CreateAutoScalingGroup(&autoscaling.CreateAutoScalingGroupInput{
+	cloud.Autoscaling().CreateAutoScalingGroupWithContext(ctx, &autoscaling.CreateAutoScalingGroupInput{
 		AutoScalingGroupName: aws.String(name),
 		DesiredCapacity:      aws.Int64(int64(count)),
 		MinSize:              aws.Int64(1),
@@ -938,7 +941,7 @@ type disabledSurgeTest struct {
 	numDetached int
 }
 
-func (m *disabledSurgeTest) DetachInstances(input *autoscaling.DetachInstancesInput) (*autoscaling.DetachInstancesOutput, error) {
+func (m *disabledSurgeTest) DetachInstancesWithContext(ctx context.Context, input *autoscaling.DetachInstancesInput, option ...request.Option) (*autoscaling.DetachInstancesOutput, error) {
 	m.mutex.Lock()
 	defer m.mutex.Unlock()
 
@@ -1233,7 +1236,7 @@ type concurrentTestAutoscaling struct {
 	ConcurrentTest *concurrentTest
 }
 
-func (m *concurrentTestAutoscaling) DetachInstances(input *autoscaling.DetachInstancesInput) (*autoscaling.DetachInstancesOutput, error) {
+func (m *concurrentTestAutoscaling) DetachInstancesWithContext(ctx context.Context, input *autoscaling.DetachInstancesInput, option ...request.Option) (*autoscaling.DetachInstancesOutput, error) {
 	m.ConcurrentTest.mutex.Lock()
 	defer m.ConcurrentTest.mutex.Unlock()
 
@@ -1315,7 +1318,7 @@ type countDetach struct {
 	Count int
 }
 
-func (c *countDetach) DetachInstances(input *autoscaling.DetachInstancesInput) (*autoscaling.DetachInstancesOutput, error) {
+func (c *countDetach) DetachInstancesWithContext(ctx context.Context, input *autoscaling.DetachInstancesInput, option ...request.Option) (*autoscaling.DetachInstancesOutput, error) {
 	c.Count += len(input.InstanceIds)
 	return &autoscaling.DetachInstancesOutput{}, nil
 }
@@ -1345,7 +1348,7 @@ type failDetachAutoscaling struct {
 	autoscalingiface.AutoScalingAPI
 }
 
-func (m *failDetachAutoscaling) DetachInstances(input *autoscaling.DetachInstancesInput) (*autoscaling.DetachInstancesOutput, error) {
+func (m *failDetachAutoscaling) DetachInstancesWithContext(ctx context.Context, input *autoscaling.DetachInstancesInput, option ...request.Option) (*autoscaling.DetachInstancesOutput, error) {
 	return nil, fmt.Errorf("testing error")
 }
 
@@ -1453,7 +1456,7 @@ type alreadyDetachedTestAutoscaling struct {
 	AlreadyDetachedTest *alreadyDetachedTest
 }
 
-func (m *alreadyDetachedTestAutoscaling) DetachInstances(input *autoscaling.DetachInstancesInput) (*autoscaling.DetachInstancesOutput, error) {
+func (m *alreadyDetachedTestAutoscaling) DetachInstancesWithContext(ctx aws.Context, input *autoscaling.DetachInstancesInput, options ...request.Option) (*autoscaling.DetachInstancesOutput, error) {
 	m.AlreadyDetachedTest.mutex.Lock()
 	defer m.AlreadyDetachedTest.mutex.Unlock()
 
