@@ -39,16 +39,12 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 		return nil
 	}
 
-	if clusterSpec.ExternalCloudControllerManager == nil && b.IsKubernetesGTE("1.24") {
+	if clusterSpec.ExternalCloudControllerManager == nil {
 		clusterSpec.ExternalCloudControllerManager = &kops.CloudControllerManagerConfig{}
 	}
 
 	eccm := clusterSpec.ExternalCloudControllerManager
 
-	if eccm == nil {
-		return nil
-	}
-
 	// No significant downside to always doing a leader election.
 	// Also, having multiple control plane nodes requires leader election.
 	eccm.LeaderElection = &kops.LeaderElectionConfiguration{LeaderElect: fi.PtrTo(true)}
@@ -79,8 +75,6 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 	if eccm.Image == "" {
 		// See https://us.gcr.io/k8s-artifacts-prod/provider-aws/cloud-controller-manager
 		switch b.KubernetesVersion.Minor {
-		case 23:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.20"
 		case 24:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.19"
 		case 25:
@@ -91,12 +85,16 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.27.6"
 		case 28:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.5"
+		case 29:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.29.2"
+		case 30:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.30.0"
 		default:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.5"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.30.0"
 		}
 	}
 
-	if b.IsKubernetesGTE("1.24") && b.IsKubernetesLT("1.25") {
+	if b.IsKubernetesLT("1.25") {
 		eccm.EnableLeaderMigration = fi.PtrTo(true)
 	}
 
