@@ -19,9 +19,9 @@ source "${REPO_ROOT}"/tests/e2e/scenarios/lib/common.sh
 
 kops-acquire-latest
 
-OVERRIDES="${OVERRIDES-} --override=cluster.spec.cloudConfig.awsEBSCSIDriver.enabled=true"
-OVERRIDES="$OVERRIDES --override=cluster.spec.snapshotController.enabled=true"
-OVERRIDES="$OVERRIDES --override=cluster.spec.certManager.enabled=true"
+OVERRIDES="${OVERRIDES-} --set=cluster.spec.cloudProvider.aws.ebsCSIDriver.enabled=true"
+OVERRIDES="$OVERRIDES --set=cluster.spec.snapshotController.enabled=true"
+OVERRIDES="$OVERRIDES --set=cluster.spec.certManager.enabled=true"
 OVERRIDES="$OVERRIDES --master-size=t3.medium --node-size=c5.large"
 
 kops-up
