@@ -23,7 +23,6 @@ import (
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 )
 
@@ -38,8 +37,8 @@ type VPCAmazonIPv6CIDRBlock struct {
 	Shared *bool
 }
 
-func (e *VPCAmazonIPv6CIDRBlock) Find(c *fi.Context) (*VPCAmazonIPv6CIDRBlock, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *VPCAmazonIPv6CIDRBlock) Find(c *fi.CloudupContext) (*VPCAmazonIPv6CIDRBlock, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	// If the VPC doesn't (yet) exist, there is no association
 	if e.VPC.ID == nil {
@@ -66,8 +65,8 @@ func (e *VPCAmazonIPv6CIDRBlock) Find(c *fi.Context) (*VPCAmazonIPv6CIDRBlock, e
 	return actual, nil
 }
 
-func (e *VPCAmazonIPv6CIDRBlock) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *VPCAmazonIPv6CIDRBlock) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *VPCAmazonIPv6CIDRBlock) CheckChanges(a, e, changes *VPCAmazonIPv6CIDRBlock) error {
@@ -111,27 +110,6 @@ func (_ *VPCAmazonIPv6CIDRBlock) RenderTerraform(t *terraform.TerraformTarget, a
 	return nil
 }
 
-type cloudformationVPCAmazonIPv6CIDRBlock struct {
-	VPCID      *cloudformation.Literal `json:"VpcId"`
-	AmazonIPv6 *bool                   `json:"AmazonProvidedIpv6CidrBlock"`
-}
-
-func (_ *VPCAmazonIPv6CIDRBlock) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *VPCAmazonIPv6CIDRBlock) error {
-	shared := aws.BoolValue(e.Shared)
-	if shared && a == nil {
-		// VPC not owned by kOps, no changes will be applied
-		// Verify that the Amazon IPv6 provided CIDR block was found.
-		return fmt.Errorf("IPv6 CIDR block provided by Amazon not found")
-	}
-
-	cf := &cloudformationVPCAmazonIPv6CIDRBlock{
-		VPCID:      e.VPC.CloudformationLink(),
-		AmazonIPv6: aws.Bool(true),
-	}
-
-	return t.RenderResource("AWS::EC2::VPCCidrBlock", *e.Name, cf)
-}
-
 func findVPCIPv6CIDR(cloud awsup.AWSCloud, vpcID *string) (*string, error) {
 	vpc, err := cloud.DescribeVPC(aws.StringValue(vpcID))
 	if err != nil {
