@@ -18,8 +18,11 @@ package azuretasks
 
 import (
 	"context"
+	"errors"
+	"fmt"
 
-	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2022-05-01/network"
+	"github.com/Azure/azure-sdk-for-go/sdk/azcore"
+	network "github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/network/armnetwork"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
@@ -56,12 +59,22 @@ func (s *Subnet) Find(c *fi.CloudupContext) (*Subnet, error) {
 	cloud := c.T.Cloud.(azure.AzureCloud)
 	l, err := cloud.Subnet().List(context.TODO(), *s.ResourceGroup.Name, *s.VirtualNetwork.Name)
 	if err != nil {
-		return nil, err
+		var azErr *azcore.ResponseError
+		if errors.As(err, &azErr) {
+			if azErr.ErrorCode == "ResourceNotFound" {
+				return nil, nil
+			} else {
+				return nil, azErr
+			}
+		} else {
+			return nil, err
+		}
 	}
+
 	var found *network.Subnet
 	for _, v := range l {
 		if *v.Name == *s.Name {
-			found = &v
+			found = v
 			break
 		}
 	}
@@ -69,6 +82,13 @@ func (s *Subnet) Find(c *fi.CloudupContext) (*Subnet, error) {
 		return nil, nil
 	}
 
+	if found.ID == nil {
+		return nil, fmt.Errorf("found subnet without ID")
+	}
+	if found.Properties == nil {
+		return nil, fmt.Errorf("found subnet without properties")
+	}
+
 	s.ID = found.ID
 
 	fs := &Subnet{
@@ -82,16 +102,16 @@ func (s *Subnet) Find(c *fi.CloudupContext) (*Subnet, error) {
 			Name: s.VirtualNetwork.Name,
 		},
 		ID:   found.ID,
-		CIDR: found.AddressPrefix,
+		CIDR: found.Properties.AddressPrefix,
 	}
-	if found.NatGateway != nil {
+	if found.Properties.NatGateway != nil {
 		fs.NatGateway = &NatGateway{
-			ID: found.NatGateway.ID,
+			ID: found.Properties.NatGateway.ID,
 		}
 	}
-	if found.NetworkSecurityGroup != nil {
+	if found.Properties.NetworkSecurityGroup != nil {
 		fs.NetworkSecurityGroup = &NetworkSecurityGroup{
-			ID: found.NetworkSecurityGroup.ID,
+			ID: found.Properties.NetworkSecurityGroup.ID,
 		}
 	}
 
@@ -129,17 +149,17 @@ func (*Subnet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Subnet) error
 	}
 
 	subnet := network.Subnet{
-		SubnetPropertiesFormat: &network.SubnetPropertiesFormat{
+		Properties: &network.SubnetPropertiesFormat{
 			AddressPrefix: e.CIDR,
 		},
 	}
 	if e.NatGateway != nil {
-		subnet.NatGateway = &network.SubResource{
+		subnet.Properties.NatGateway = &network.SubResource{
 			ID: e.NatGateway.ID,
 		}
 	}
 	if e.NetworkSecurityGroup != nil {
-		subnet.NetworkSecurityGroup = &network.SecurityGroup{
+		subnet.Properties.NetworkSecurityGroup = &network.SecurityGroup{
 			ID: e.NetworkSecurityGroup.ID,
 		}
 	}
