@@ -145,6 +145,8 @@ type NewClusterOptions struct {
 	Topology string
 	// DNSType is the DNS type to use; "public" or "private". Defaults to "public".
 	DNSType string
+	// DNSZone is the DNS zone to use.
+	DNSZone string
 
 	// APILoadBalancerClass determines whether to use classic or network load balancers for the API
 	APILoadBalancerClass string
@@ -162,8 +164,8 @@ type NewClusterOptions struct {
 	NodeImage         string
 	ControlPlaneImage string
 	BastionImage      string
-	ControlPlaneSize  string
-	NodeSize          string
+	ControlPlaneSizes []string
+	NodeSizes         []string
 }
 
 func (o *NewClusterOptions) InitDefaults() {
@@ -694,8 +696,8 @@ func setupZones(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.Stri
 				return nil, err
 			}
 
-			// We create default subnets named the same as the regions
-			subnetName := location
+			// We create default subnets named the same as the cluster
+			subnetName := cluster.Name
 
 			subnet := model.FindSubnet(cluster, subnetName)
 			if subnet == nil {
@@ -897,10 +899,12 @@ func setupControlPlane(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubne
 			g.ObjectMeta.Name = "control-plane-" + name
 
 			subnets := zoneToSubnetsMap[zone]
-			if len(subnets) == 0 {
+			switch len(subnets) {
+			case 0:
 				klog.Fatalf("subnet not found in zoneToSubnetsMap")
-			}
-			for _, subnet := range subnets {
+			default:
+				// Use only the main subnet for control-plane nodes
+				subnet := subnets[0]
 				if opt.IPv6 && opt.Topology == api.TopologyPrivate {
 					g.Spec.Subnets = append(g.Spec.Subnets, "dualstack-"+subnet.Name)
 				} else {
@@ -918,7 +922,18 @@ func setupControlPlane(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubne
 				}
 			}
 
-			g.Spec.MachineType = opt.ControlPlaneSize
+			for i, size := range opt.ControlPlaneSizes {
+				if i == 0 {
+					g.Spec.MachineType = size
+				}
+				if cloudProvider == api.CloudProviderAWS && len(opt.ControlPlaneSizes) > 1 {
+					if g.Spec.MixedInstancesPolicy == nil {
+						g.Spec.MixedInstancesPolicy = &api.MixedInstancesPolicySpec{}
+
+					}
+					g.Spec.MixedInstancesPolicy.Instances = append(g.Spec.MixedInstancesPolicy.Instances, size)
+				}
+			}
 			g.Spec.Image = opt.ControlPlaneImage
 
 			controlPlanes = append(controlPlanes, g)
@@ -1003,6 +1018,43 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetsMap m
 
 	var nodes []*api.InstanceGroup
 
+	if featureflag.AWSSingleNodesInstanceGroup.Enabled() && cloudProvider == api.CloudProviderAWS && len(opt.SubnetIDs) == 0 {
+		nodeCount := opt.NodeCount
+		if nodeCount == 0 {
+			nodeCount = 1
+		}
+
+		g := &api.InstanceGroup{}
+		g.Spec.Role = api.InstanceGroupRoleNode
+		g.Spec.MinSize = fi.PtrTo(nodeCount)
+		g.Spec.MaxSize = fi.PtrTo(nodeCount)
+		g.ObjectMeta.Name = "nodes"
+
+		for _, zone := range opt.Zones {
+			subnets := zoneToSubnetsMap[zone]
+			for _, subnet := range subnets[1:] {
+				g.Spec.Subnets = append(g.Spec.Subnets, subnet.Name)
+			}
+		}
+
+		for i, size := range opt.NodeSizes {
+			if i == 0 {
+				g.Spec.MachineType = size
+			}
+			if len(opt.NodeSizes) > 1 {
+				if g.Spec.MixedInstancesPolicy == nil {
+					g.Spec.MixedInstancesPolicy = &api.MixedInstancesPolicySpec{}
+
+				}
+				g.Spec.MixedInstancesPolicy.Instances = append(g.Spec.MixedInstancesPolicy.Instances, size)
+			}
+		}
+		g.Spec.Image = opt.NodeImage
+
+		nodes = append(nodes, g)
+		return nodes, nil
+	}
+
 	// The node count is the number of zones unless explicitly set
 	// We then divvy up amongst the zones
 	numZones := len(opt.Zones)
@@ -1028,11 +1080,16 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetsMap m
 		g.ObjectMeta.Name = "nodes-" + zone
 
 		subnets := zoneToSubnetsMap[zone]
-		if len(subnets) == 0 {
+		switch len(subnets) {
+		case 0:
 			klog.Fatalf("subnet not found in zoneToSubnetsMap")
-		}
-		for _, subnet := range subnets {
-			g.Spec.Subnets = append(g.Spec.Subnets, subnet.Name)
+		case 1:
+			g.Spec.Subnets = append(g.Spec.Subnets, subnets[0].Name)
+		default:
+			// The main subnet may be smaller and should not be used for worker nodes
+			for _, subnet := range subnets[1:] {
+				g.Spec.Subnets = append(g.Spec.Subnets, subnet.Name)
+			}
 		}
 
 		if cloudProvider == api.CloudProviderGCE || cloudProvider == api.CloudProviderAzure {
@@ -1052,10 +1109,23 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetsMap m
 			if g.Spec.NodeLabels == nil {
 				g.Spec.NodeLabels = make(map[string]string)
 			}
-			g.Spec.NodeLabels["cloud.google.com/metadata-proxy-ready"] = "true"
+			if cluster.IsKubernetesLT("1.29") {
+				g.Spec.NodeLabels["cloud.google.com/metadata-proxy-ready"] = "true"
+			}
 		}
 
-		g.Spec.MachineType = opt.NodeSize
+		for i, size := range opt.NodeSizes {
+			if i == 0 {
+				g.Spec.MachineType = size
+			}
+			if cloudProvider == api.CloudProviderAWS && len(opt.NodeSizes) > 1 {
+				if g.Spec.MixedInstancesPolicy == nil {
+					g.Spec.MixedInstancesPolicy = &api.MixedInstancesPolicySpec{}
+
+				}
+				g.Spec.MixedInstancesPolicy.Instances = append(g.Spec.MixedInstancesPolicy.Instances, size)
+			}
+		}
 		g.Spec.Image = opt.NodeImage
 
 		nodes = append(nodes, g)
@@ -1197,6 +1267,12 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 	}
 
 	cluster.Spec.Networking.Topology = &api.TopologySpec{}
+
+	err := setupDNSTopology(opt, cluster)
+	if err != nil {
+		return nil, err
+	}
+
 	switch opt.Topology {
 	case api.TopologyPublic:
 
@@ -1335,26 +1411,22 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 		}
 	}
 
-	err := setupDNSTopology(opt, cluster)
-	if err != nil {
-		return nil, err
-	}
 	return bastions, nil
 }
 
 func setupDNSTopology(opt *NewClusterOptions, cluster *api.Cluster) error {
 	switch strings.ToLower(opt.DNSType) {
 	case "":
-		switch cluster.Spec.GetCloudProvider() {
-		case api.CloudProviderHetzner, api.CloudProviderDO, api.CloudProviderAzure:
-			// Use dns=none if not specified
-			cluster.Spec.Networking.Topology.DNS = api.DNSTypeNone
-		default:
+		if opt.DNSZone != "" {
+			// Use dns=public if zone is specified
+			cluster.Spec.Networking.Topology.DNS = api.DNSTypePublic
+		} else {
 			if cluster.UsesLegacyGossip() {
-				cluster.Spec.Networking.Topology.DNS = api.DNSTypePrivate
-			} else {
-				cluster.Spec.Networking.Topology.DNS = api.DNSTypePublic
+				// Warn about using dns=none instead of Gossip
+				klog.Warningf("Gossip is deprecated, using None DNS instead")
 			}
+			// Default to dns=none instead of dns=public for all cloud providers
+			cluster.Spec.Networking.Topology.DNS = api.DNSTypeNone
 		}
 	case "public":
 		cluster.Spec.Networking.Topology.DNS = api.DNSTypePublic
