@@ -50,8 +50,7 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	apiModel "k8s.io/kops/pkg/apis/kops/model"
 	"k8s.io/kops/pkg/apis/kops/util"
-	"k8s.io/kops/pkg/apis/nodeup"
-	"k8s.io/kops/pkg/dns"
+	"k8s.io/kops/pkg/bootstrap/pkibootstrap"
 	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/pkg/flagbuilder"
 	"k8s.io/kops/pkg/kubemanifest"
@@ -135,11 +134,14 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 		}
 		return false
 	}
-	dest["GossipName"] = func() bool {
-		if dns.IsGossipClusterName(cluster.Name) {
-			return true
+	dest["PublishesDNSRecords"] = func() bool {
+		return cluster.PublishesDNSRecords()
+	}
+	dest["ClusterDNSDomain"] = func() string {
+		if cluster.UsesLegacyGossip() {
+			return "k8s.local"
 		}
-		return false
+		return cluster.Name
 	}
 
 	dest["NodeLocalDNSClusterIP"] = func() string {
@@ -382,10 +384,6 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 
 	dest["ParseTaint"] = util.ParseTaint
 
-	dest["UsesInstanceIDForNodeName"] = func() bool {
-		return nodeup.UsesInstanceIDForNodeName(tf.Cluster)
-	}
-
 	dest["KarpenterEnabled"] = func() bool {
 		return cluster.Spec.Karpenter != nil && cluster.Spec.Karpenter.Enabled
 	}
@@ -480,10 +478,8 @@ func (tf *TemplateFunctions) ControlPlaneControllerReplicas(deployOnWorkersIfExt
 func (tf *TemplateFunctions) APIServerNodeRole() string {
 	if featureflag.APIServerNodes.Enabled() {
 		return "node-role.kubernetes.io/api-server"
-	} else if tf.Cluster.IsKubernetesGTE("1.24") {
-		return "node-role.kubernetes.io/control-plane"
 	}
-	return "node-role.kubernetes.io/master"
+	return "node-role.kubernetes.io/control-plane"
 }
 
 // HasHighlyAvailableControlPlane returns true of the cluster has more than one control plane node. False otherwise.
@@ -699,6 +695,10 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 			CertNames:             certNames,
 		}
 
+		if featureflag.Metal.Enabled() {
+			config.Server.PKI = &pkibootstrap.Options{}
+		}
+
 		switch cluster.Spec.GetCloudProvider() {
 		case kops.CloudProviderAWS:
 			nodesRoles := sets.String{}
@@ -731,10 +731,6 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 				Region:     tf.Region,
 			}
 
-			if cluster.Spec.ExternalCloudControllerManager != nil {
-				config.Server.UseInstanceIDForNodeName = true
-			}
-
 		case kops.CloudProviderGCE:
 			c := tf.cloud.(gce.GCECloud)
 
@@ -962,7 +958,7 @@ func (tf *TemplateFunctions) GetClusterAutoscalerNodeGroups() map[string]Cluster
 			if cluster.Spec.GetCloudProvider() == kops.CloudProviderGCE {
 				cloud := tf.cloud.(gce.GCECloud)
 				format := "https://www.googleapis.com/compute/v1/projects/%s/zones/%s/instanceGroups/%s"
-				group.Other = fmt.Sprintf(format, cloud.Project(), ig.Spec.Zones[0], gce.NameForInstanceGroupManager(cluster, ig, ig.Spec.Zones[0]))
+				group.Other = fmt.Sprintf(format, cloud.Project(), ig.Spec.Zones[0], gce.NameForInstanceGroupManager(cluster.ObjectMeta.Name, ig.ObjectMeta.Name, ig.Spec.Zones[0]))
 			} else {
 				group.Other = ig.Name + "." + cluster.Name
 			}
