@@ -31,6 +31,8 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/service/s3"
+	"go.opentelemetry.io/otel/attribute"
+	"go.opentelemetry.io/otel/trace"
 	"k8s.io/klog/v2"
 
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
@@ -90,9 +92,7 @@ func (p *S3Path) String() string {
 	return p.Path()
 }
 
-func (p *S3Path) Remove() error {
-	ctx := context.TODO()
-
+func (p *S3Path) Remove(ctx context.Context) error {
 	client, err := p.client(ctx)
 	if err != nil {
 		return err
@@ -114,15 +114,13 @@ func (p *S3Path) Remove() error {
 	return nil
 }
 
-func (p *S3Path) RemoveAll() error {
-	ctx := context.TODO()
-
+func (p *S3Path) RemoveAll(ctx context.Context) error {
 	client, err := p.client(ctx)
 	if err != nil {
 		return err
 	}
 
-	tree, err := p.ReadTree()
+	tree, err := p.ReadTree(ctx)
 	if err != nil {
 		return err
 	}
@@ -165,9 +163,7 @@ func (p *S3Path) RemoveAll() error {
 	return nil
 }
 
-func (p *S3Path) RemoveAllVersions() error {
-	ctx := context.TODO()
-
+func (p *S3Path) RemoveAllVersions(ctx context.Context) error {
 	client, err := p.client(ctx)
 	if err != nil {
 		return err
@@ -292,6 +288,9 @@ func (p *S3Path) getRequestACL(aclObj ACL) (*string, error) {
 }
 
 func (p *S3Path) WriteFile(ctx context.Context, data io.ReadSeeker, aclObj ACL) error {
+	ctx, span := tracer.Start(ctx, "S3Path::WriteFile", trace.WithAttributes(attribute.String("path", p.String())))
+	defer span.End()
+
 	client, err := p.client(ctx)
 	if err != nil {
 		return err
@@ -352,8 +351,11 @@ func (p *S3Path) CreateFile(ctx context.Context, data io.ReadSeeker, acl ACL) er
 
 // ReadFile implements Path::ReadFile
 func (p *S3Path) ReadFile(ctx context.Context) ([]byte, error) {
+	ctx, span := tracer.Start(ctx, "S3Path::ReadFile", trace.WithAttributes(attribute.String("path", p.String())))
+	defer span.End()
+
 	var b bytes.Buffer
-	_, err := p.WriteTo(&b)
+	_, err := p.WriteToWithContext(ctx, &b)
 	if err != nil {
 		return nil, err
 	}
@@ -363,6 +365,11 @@ func (p *S3Path) ReadFile(ctx context.Context) ([]byte, error) {
 // WriteTo implements io.WriterTo
 func (p *S3Path) WriteTo(out io.Writer) (int64, error) {
 	ctx := context.TODO()
+	return p.WriteToWithContext(ctx, out)
+}
+
+// WriteToWithContext implements io.WriterTo, but adds a context
+func (p *S3Path) WriteToWithContext(ctx context.Context, out io.Writer) (int64, error) {
 	client, err := p.client(ctx)
 	if err != nil {
 		return 0, err
@@ -438,8 +445,10 @@ func (p *S3Path) ReadDir() ([]Path, error) {
 	return paths, nil
 }
 
-func (p *S3Path) ReadTree() ([]Path, error) {
-	ctx := context.TODO()
+func (p *S3Path) ReadTree(ctx context.Context) ([]Path, error) {
+	ctx, span := tracer.Start(ctx, "S3Path::ReadTree")
+	defer span.End()
+
 	client, err := p.client(ctx)
 	if err != nil {
 		return nil, err
@@ -491,7 +500,7 @@ func (p *S3Path) client(ctx context.Context) (*s3.S3, error) {
 		return nil, err
 	}
 
-	client, err := p.s3Context.getClient(bucketDetails.region)
+	client, err := p.s3Context.getClient(ctx, bucketDetails.region)
 	if err != nil {
 		return nil, err
 	}
@@ -638,6 +647,12 @@ type terraformDOFile struct {
 	Content *terraformWriter.Literal `json:"content,omitempty" cty:"content"`
 }
 
+type terraformScwFile struct {
+	Bucket  string                   `json:"bucket" cty:"bucket"`
+	Key     string                   `json:"key" cty:"key"`
+	Content *terraformWriter.Literal `json:"content,omitempty" cty:"content"`
+}
+
 func (p *S3Path) RenderTerraform(w *terraformWriter.TerraformWriter, name string, data io.Reader, acl ACL) error {
 	ctx := context.TODO()
 
@@ -669,6 +684,21 @@ func (p *S3Path) RenderTerraform(w *terraformWriter.TerraformWriter, name string
 		}
 		return w.RenderResource("digitalocean_spaces_bucket_object", name, tf)
 
+		// render Scaleway's Terraform objects
+	} else if p.scheme == "scw" {
+
+		content, err := w.AddFileBytes("scaleway_object", name, "content", bytes, false)
+		if err != nil {
+			return fmt.Errorf("error rendering Scaleway file: %w", err)
+		}
+
+		tf := terraformScwFile{
+			Bucket:  p.Bucket(),
+			Key:     p.Key(),
+			Content: content,
+		}
+		return w.RenderResource("scaleway_object", name, tf)
+
 	} else {
 		bucketDetails, err := p.getBucketDetails(ctx)
 		if err != nil {
